@@ -68,6 +68,22 @@ def get_admin_model(orm_model_cls: str | Any) -> ModelAdmin | None:
     return None
 
 
+def get_admin_or_admin_inline_model(orm_model_cls: str | Any) -> ModelAdmin | InlineModelAdmin | None:
+    """This method is used to get an admin model class or an inline model class by orm model class name.
+
+    :params orm_model_cls_name: a name of model.
+    :return: An admin model class or an inline model class or None.
+    """
+    admin_model = get_admin_model(orm_model_cls)
+    if admin_model:
+        return admin_model
+    for _, admin_model in admin_models.items():
+        for inline_model in admin_model.inlines:
+            if inline_model.model.__name__ == orm_model_cls:
+                return inline_model(inline_model.model)
+    return None
+
+
 def generate_models_schema(
     admin_models: dict[Any, ModelAdmin | InlineModelAdmin],
     user_id: UUID | int | None = None,
